==> storage-manager-wrapper-2.2.0-20150612.114405-38-sources.jar: org/gcube/contentmanager/storageclient/protocol/utils/Utils.java <==
package org.gcube.contentmanager.storageclient.protocol.utils;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;

import org.gcube.common.scope.impl.ScopeBean;
import org.gcube.common.scope.impl.ScopeBean.Type;
import org.gcube.common.scope.impl.ServiceMapScannerMediator;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class Utils {
	
	// Temporary CONSTANTS	
		private static final String GCUBE_RESOLVER_HOST = "data.gcube.org";
		private static final String D4SCIENCE_RESOLVER_HOST = "data.d4science.org";	
		private static final String GCUBE_INFRA = "gcube";
		private static final String D4SCIENCE_INFRA = "d4science.research-infrastructures.eu";
		private static final String SCOPE_INFRA = "SCOPE";
		
		public static final String INFRASTRUCTURE_ENV_VARIABLE_NAME="infrastructure";
	
	private static final Logger logger = LoggerFactory.getLogger(Utils.class);
	
//	public static boolean validationScope(String scope){
//		ScopeBean scopeBean=new ScopeBean(scope);
//		if((scopeBean.is(Type.VRE)))
//			scope=scopeBean.enclosingScope().toString();
//		Set<String> scopeSet=new ServiceMapScannerMediator().getScopeKeySet();
//		for(String scopeItem : scopeSet){
//			logger.debug("scope scanned: "+scopeItem);
//			if(scope.equals(scopeItem))
//				return true;
//		}
//		return false;
//	}
//	
	
	public static boolean validationScope2(String scope){
		ScopeBean scopeBean=new ScopeBean(scope);
		if((scopeBean.is(Type.VRE)))
			scope=scopeBean.enclosingScope().toString();
		return new ServiceMapScannerMediator().isValid(scope);
	}
	
	public static ArrayList<String> getVOScopes(String scope){
		ArrayList<String> vos=new ArrayList<String>();
		ScopeBean scopeBean=new ScopeBean(scope);
		//retrieve INFRA scope
		while(!scopeBean.is(Type.INFRASTRUCTURE)){
			logger.debug("the scope "+scope+" is not an INFRA scope ");
			scopeBean=new ScopeBean(scopeBean.enclosingScope().toString());
		}
		scope=scopeBean.toString();
		if(scopeBean.is(Type.INFRASTRUCTURE)){
			Set<String> scopeSet=new ServiceMapScannerMediator().getScopeKeySet();
			for(String scopeItem : scopeSet){
				//retrieve all Vo scopes
				logger.debug("scope scanned: "+scopeItem);
				if(scopeItem.contains(scope) && (new ScopeBean(scopeItem).is(Type.VO))){
					logger.debug("found vo scope: "+scopeItem);
					vos.add(scopeItem);
				}
			}
		}
		return vos;
	}
	
	public static String extractInfrastructureNewVersion(String urlParam){
		logger.debug("urlParam: "+urlParam);
		String infra= checkVarEnv(INFRASTRUCTURE_ENV_VARIABLE_NAME);
		if (infra != null)
			return infra;
		else
			//only for test return the infra from the uri. In prod will be throws a runtime exception
			return getInfraFromResolverHost(urlParam);
//			return urlParam;
//			throw new RuntimeException("environment variable called "+INFRASTRUCTURE_ENV_VARIABLE_NAME+" not set");
	}
	
	public static String getInfraFromResolverHost(String resolverHost) {
		if(resolverHost.equals(GCUBE_RESOLVER_HOST)){
			return GCUBE_INFRA;
		}else if(resolverHost.equals(D4SCIENCE_RESOLVER_HOST)){
			return D4SCIENCE_INFRA;
		}else return resolverHost;
	}

	public static String checkVarEnv(String name){
		Map<String, String> env = System.getenv();
        TreeSet<String> keys = new TreeSet<String>(env.keySet());
        
        Iterator<String> iter = keys.iterator();
        String infra=null;
        while(iter.hasNext())
        {
            String key = iter.next();
            if(key.equalsIgnoreCase(name)){
            	infra=env.get(key);
            	break;
            }
        }
        return infra;
	}


}

==> storage-manager-wrapper-2.2.1-20151221.112430-84-sources.jar: org/gcube/contentmanager/storageclient/protocol/utils/Utils.java <==
package org.gcube.contentmanager.storageclient.protocol.utils;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;

import org.gcube.common.scope.impl.ScopeBean;
import org.gcube.common.scope.impl.ScopeBean.Type;
import org.gcube.common.scope.impl.ServiceMapScannerMediator;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
 *
 * Utility class for scope identity
 *
 * @author Roberto Cirillo (ISTI-CNR)
 
 */
public class Utils {
	
	// Temporary CONSTANTS	
		private static final String GCUBE_RESOLVER_HOST = "data.gcube.org";
		private static final String D4SCIENCE_RESOLVER_HOST = "data.d4science.org";	
		private static final String GCUBE_INFRA = "gcube";
		private static final String D4SCIENCE_INFRA = "d4science.research-infrastructures.eu";
		public static final String INFRASTRUCTURE_ENV_VARIABLE_NAME="infrastructure";
	
	private static final Logger logger = LoggerFactory.getLogger(Utils.class);
	
	
	public static boolean validationScope2(String scope){
		ScopeBean scopeBean=new ScopeBean(scope);
		if((scopeBean.is(Type.VRE)))
			scope=scopeBean.enclosingScope().toString();
		return ServiceMapScannerMediator.isValid(scope);
	}
	
	public static ArrayList<String> getVOScopes(String scope){
		ArrayList<String> vos=new ArrayList<String>();
		ScopeBean scopeBean=new ScopeBean(scope);
		//retrieve INFRA scope
		while(!scopeBean.is(Type.INFRASTRUCTURE)){
			logger.debug("the scope "+scope+" is not an INFRA scope ");
			scopeBean=new ScopeBean(scopeBean.enclosingScope().toString());
		}
		scope=scopeBean.toString();
		if(scopeBean.is(Type.INFRASTRUCTURE)){
			Set<String> scopeSet=ServiceMapScannerMediator.getScopeKeySet();
			for(String scopeItem : scopeSet){
				//retrieve all Vo scopes
				logger.debug("scope scanned: "+scopeItem);
				if(scopeItem.contains(scope) && (new ScopeBean(scopeItem).is(Type.VO))){
					logger.debug("found vo scope: "+scopeItem);
					vos.add(scopeItem);
				}
			}
		}
		return vos;
	}
	
	public static String extractInfrastructureNewVersion(String urlParam){
		logger.debug("urlParam: "+urlParam);
		String infra= checkVarEnv(INFRASTRUCTURE_ENV_VARIABLE_NAME);
		if (infra != null)
			return infra;
		else
			//only for test return the infra from the uri. In prod will be throws a runtime exception
			return getInfraFromResolverHost(urlParam);
	}
	
	public static String getInfraFromResolverHost(String resolverHost) {
		if(resolverHost.equals(GCUBE_RESOLVER_HOST)){
			return GCUBE_INFRA;
		}else if(resolverHost.equals(D4SCIENCE_RESOLVER_HOST)){
			return D4SCIENCE_INFRA;
		}else return resolverHost;
	}

	public static String checkVarEnv(String name){
		Map<String, String> env = System.getenv();
        TreeSet<String> keys = new TreeSet<String>(env.keySet());
        Iterator<String> iter = keys.iterator();
        String infra=null;
        while(iter.hasNext())
        {
            String key = iter.next();
            if(key.equalsIgnoreCase(name)){
            	infra=env.get(key);
            	break;
            }
        }
        return infra;
	}


}
